# -*- coding: utf-8 -*-
"""
ajax module for jmb.quotation
"""

from dajax.core import Dajax
from dajaxice.decorators import dajaxice_register

from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from django.db.models import Q
from django.utils.translation import ugettext as _

from jmb.organization.models import Organization, Contact
from jmb.payment.models import PaymentForm
from jmb.project.models import Project
from jmb.store.models import StoreCause
from jmb.currency.models import Currency
from jmb.carriage.models import Delivery
from jmb.product.models import Product
from jmb.vat.models import Vat
from jmb.price.models import OrganizationPriceList, PriceListItem

@dajaxice_register
def on_select_recipient(request, *args, **kwargs):
    dajax = Dajax()
    return dajax.json()

@dajaxice_register
def on_select_owner(request, *args, **kwargs):
    '''
    ritorna l html delle select filtrate per owner scelto
    
    - contact (persona: contatti presi dall'owner)
    - project (progetto: i progetti presi dall'owner)
    - payment_form (forma di pagamento: default deve essere quella
         dell'owner con possibilità  di modifica)
    - store_cause (causale di magazzino: in funzione della tipologia
         di preventivo, acquisto o vendita, presentare la causale corretta)
    - price_list (listino: default quello dell'owner)
    - delivery (consegna: default quella dell'owner)
    - currency (valuta: default deve essere quella dell'owner)
    - vat (iva: default deve essere quella dell'owner)
    - shipping_address (indirizzo di spedizione: solo quelli dell'owner)
    '''
    dajax = Dajax()
    options = "<option>%s</option>" % ("-"*9)
    dajax.assign('#id_contact', 'innerHTML', options)
    dajax.assign('#id_project', 'innerHTML', options)
    dajax.assign('#id_payment_form', 'innerHTML', options)
    dajax.assign('#id_store_cause', 'innerHTML', options)
    dajax.assign('#id_currency', 'innerHTML', options)
    dajax.assign('#id_delivery', 'innerHTML', options)
    dajax.assign('#id_vat', 'innerHTML', options)
    dajax.assign('#id_shipping_address', 'innerHTML', options)
    
    try:
        organization = Organization.objects.get(id=kwargs['id_owner']) 
        contacts = organization.contacts.all()
        projects = Project.objects.filter(organization=organization, status=1)
        payment_forms = PaymentForm.objects.all()
        currencies = Currency.objects.all()
        deliveries = Delivery.objects.all()
        vats = Vat.objects.all()
        shipping_addresses = organization.get_shipping_addresses()
        # TODO: FIXED
        store_causes = StoreCause.objects.filter(
            category=organization.organization_type.category
        )
    except ObjectDoesNotExist, KeyError:
        return dajax.json()

    options = "<option>%s</option>" % ("-"*9)
    for contact in contacts:
        options += "<option value='%s'>%s</option>" % (contact.id, str(contact))
    dajax.assign('#id_contact', 'innerHTML', options)
    
    options = "<option>%s</option>" % ("-"*9)
    for project in projects:
        options += "<option value='%s'>%s</option>" % (project.id, str(project))
    dajax.assign('#id_project', 'innerHTML', options)
    
    options = "<option>%s</option>" % ("-"*9)    
    for payment_form in payment_forms:
        options += "<option value='%s' %s>%s</option>" % (
            payment_form.id,
            "selected=selected" if payment_form == organization.payment_form
            else '', str(payment_form)
            )
    dajax.assign('#id_payment_form', 'innerHTML', options)

    # TODO: FIXED - LA CAUSALE DI MAGAZZINO È OBBLICATORIA E SE È UNICA NON PROPONGO LA SCELTA
    options = ""
    if store_causes.count() > 1:
        options = "<option>%s</option>" % ("-"*9)
    for store_cause in store_causes:
        options += "<option value='%s'>%s</option>" % (
            store_cause.id, str(store_cause)
            )
    dajax.assign('#id_store_cause', 'innerHTML', options)
    
    options = "<option>%s</option>" % ("-"*9)    
    for currency in currencies:
        options += "<option value='%s' %s>%s</option>" % (
            currency.id,
            "selected=selected" if currency == organization.currency
            else '', str(currency)
        )
    dajax.assign('#id_currency', 'innerHTML', options)
    
    options = "<option>%s</option>" % ("-"*9)    
    for delivery in deliveries:
        options += "<option value='%s' %s>%s</option>" % (
            delivery.id,
            "selected=selected" if delivery == organization.delivery
            else '', str(delivery)
            )
    dajax.assign('#id_delivery', 'innerHTML', options)
    
    options = "<option>%s</option>" % ("-"*9)    
    for vat in vats:
        options += "<option value='%s' %s>%s</option>" % (
            vat.id,
            "selected=selected" if vat == organization.vat
            else '', str(vat)
            )
    dajax.assign('#id_vat', 'innerHTML', options)
    
    options = "<option>%s</option>" % ("-"*9)
    for shipping_address in shipping_addresses:
        options += "<option value='%s'>%s</option>" % (
            shipping_address.id, str(shipping_address))
    dajax.assign('#id_shipping_address', 'innerHTML', options)

    return dajax.json()

@dajaxice_register
def on_select_product(request, *args, **kwargs):
    '''
    ritorna l html delle select filtrate per prodotto scelto
    (per quotationrow)
    - vat (in funzione dell'owner e del prodotto scelto) - default dell owner
    - store_cause (in funzione dell'owner e del prodotto scelto) default prodotto
    - price (in funzione dell'owner e del prodotto scelto - listino attivo)
    - m_unit (in funzione del prodotto scelto)
    kwargs['id_vat'],kwargs['id_project'] ecc..
    rappresenta l'id dinamico dell input della row
    '''
    dajax = Dajax()
    options = "<option>%s</option>" % ("-"*9)
    # TODO: FIXME
    # dajax.assign('#' + kwargs['id_project'], 'innerHTML', options)
    dajax.assign('#' + kwargs['id_vat'], 'innerHTML', options)
    dajax.assign('#' + kwargs['id_store_cause'], 'innerHTML', options)
    dajax.assign('#' + kwargs['id_m_unit'], 'innerHTML', options)
    dajax.assign('#' + kwargs['price'], 'innerHTML', options)
    
    try:
        organization = Organization.objects.get(id=kwargs['id_owner']) 
        product = Product.objects.get(id=kwargs['id_product'])
    except:
        return dajax.json()

    try:
        vat_choosed = kwargs['id_vat_choosed']
    except KeyError:
        vat_choosed = None
    
    try:
        store_cause_choosed = kwargs['id_store_cause_choosed']
    except  KeyError:
        store_cause_choosed = None

    projects = organization.projects.all()
    options = ""
    if projects.count() > 1:
        options = "<option>%s</option>" % ("-"*9)

    for project in projects:
        options += "<option value='%s'>%s</option>" % (project.id, str(project))
# TODO: FIXME
#    dajax.assign('#' + kwargs['id_project'], 'innerHTML', options)

    vats = Vat.objects.filter(
        Q(organizations__in=(organization,))|
        Q(products__in=(product,))
    ).distinct()

    options = ""
    if vats.count() > 1:
        options = "<option>%s</option>" % ("-"*9)

    for vat in vats:
        options += "<option value='%s' %s>%s: %s</option>" % (vat.id,
            "selected=selected" if vat.id == vat_choosed  else '',
            _("Owner") if vat.id == vat_choosed  else  _('Product'),
            str(vat)
        )
    dajax.assign('#' + kwargs['id_vat'], 'innerHTML', options)


    store_causes = StoreCause.objects.filter(
        Q(category=organization.organization_type.category)|
        Q(products__in=(product,))
    ).distinct()

    options = ""
    if store_causes.count() > 1:
        options = "<option>%s</option>" % ("-"*9)

    for store_cause in store_causes:
        
        options += "<option value='%s' %s>%s: %s</option>" % (store_cause.id,
            '' if store_cause.id == store_cause_choosed  else 'selected=selected',
            _("Owner") if store_cause.id == store_cause_choosed  else  _('Product'),
            str(store_cause)
        )

    dajax.assign('#' + kwargs['id_store_cause'], 'innerHTML', options)

    try:
        price_list = OrganizationPriceList.objects.get(organization=organization)
        priceitem = PriceListItem.objects.get(price_list=price_list, product=product)
        value = priceitem.price
        dajax.assign('#' + kwargs['price'], 'value', value)
    except Exception, ObjectDoesNotExist:
        pass

    options = ""
    for m_unit in settings.PRODUCT_PRODUCT_UNIT_TYPE:
        options += "<option value='%s' %s>%s</option>" % (
            m_unit[0],
            "selected=selected" if m_unit[0] == product.m_unit else '',
            m_unit[1]
        )

        dajax.assign('#' + kwargs['id_m_unit'], 'innerHTML', options)
    
    return dajax.json()
