# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.core.urlresolvers import reverse
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.quotation.models import Quotation
from jmb.jadmin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Quotation",
            'display': "tabs",
            'children': [Models(), ]
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class QuotationDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Quotation",
            'display': "tabs",
            'children': [QuotationModels(), ]
        })
        super(QuotationDashboard, self).__init__(**kwargs)


class QuotationModels(modules.ModelList):
    def init_with_context(self, context):
        if self._initialized:
            return
        self.title = _("Main Models")
        supplier_model_dict = {
            'title': _('Quotation Supplier'),
            'change_url': reverse('admin:quotation_quotation_supplier_changelist'),
            'add_url': reverse('admin:quotation_quotation_supplier_add')
        }
        customer_model_dict = {
            'title': _('Quotation Customer'),
            'change_url': reverse('admin:quotation_quotation_customer_changelist'),
            'add_url': reverse('admin:quotation_quotation_customer_add')
        }
        self.children.append(supplier_model_dict)
        self.children.append(customer_model_dict)
        items = self._visible_models(context['request'])
        if not items:
            return

        self._initialized = True


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Main Models"),
            'models': ('jmb.quotation.models.*',),
        })
        super(Models, self).__init__(**kwargs)


class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Others"),
            'models': (),
        }
        super(OtherModels, self).__init__(**kwargs)


# class Settings(modules.ModelList):
#     def __init__(self, **kwargs):
#         kwargs =  {
#             'title': _("Settings"),
#             'models':['jmb.quotation.models.Settings',],
#             }
#         super(Settings, self).__init__(**kwargs)

class Permissions(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Permissions"),
            'models': ['jmb.quotation.models.QuotationPermissions', ],
        }
        super(Permissions, self).__init__(**kwargs)


class CustomModule(modules.DashboardModule):
    """Esempio di modulo che produce contentuto generico
    """

    def __init__(self, title, template='admin_tools/quotation/custom.html',
                 order_by=None, limit=10, qs=Quotation.objects.all(), extra_filters={},
                 children=None, **kwargs):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs = {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(CustomModule, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs


class DefaultAppDashboard(AppIndexDashboard):
    #    class Media:
    #        css = ('office_thunder/css/dashboard.css',)
    #
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 2

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(QuotationDashboard, 'jmb.quotation')
# Used in /admin/Quotation
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.quotation')
