# -*- coding: utf-8 -*-
from django import forms
from django.utils.translation import ugettext_lazy as _

import autocomplete_light
from multi_email_field.forms import MultiEmailField

from jmb.jadmin import ConstrainedModelForm
from jmb.core.forms.models import AdminModelForm

from jmb.quotation.models import Quotation, QuotationRow
from jmb.organization.models import Organization, Contact


class QuotationRowForm(ConstrainedModelForm):

    hidden_fields = ('quotation',)

    def __init__(self, *args, **kwargs):
        super(QuotationRowForm, self).__init__(*args, **kwargs)
        quotation_id = False
        obj = kwargs.pop('instance', False)
        if obj:
            quotation = obj.quotation
            quotation_id = quotation.id

        if self.data.get("quotation", False):
            quotation_id = self.data.get("quotation", False)

        if self.initial.get("quotation", False):
            quotation_id = self.initial.get("quotation", False)

        if quotation_id:
            quotation = Quotation.objects.get(id=quotation_id)
            self.fields['quotation'] = forms.ModelChoiceField(
                queryset=Quotation.objects.all(), required=False,
                widget=forms.widgets.HiddenInput()
            )

    class Meta:
        model = QuotationRow
        fields = '__all__'

class QuotationAdminForm(AdminModelForm):

    owner = forms.ModelChoiceField(
        Organization.objects.all(),
        #queryset=[],
        required=True,
        widget=autocomplete_light.ChoiceWidget('Organization',)
    )
    recipient = forms.ModelChoiceField(
        Organization.objects.all(),
        #queryset=[],
        required=True,
        widget=autocomplete_light.ChoiceWidget('RecipientAutocomplete',)
    )

    class Meta:
        model = Quotation
        fields = '__all__'


class CusQuotationAdminForm(QuotationAdminForm):
    owner = forms.ModelChoiceField(
        Organization.objects.all(), required=True,
        widget=autocomplete_light.ChoiceWidget('CustomerOrganization',)
    )
    recipient = forms.ModelChoiceField(
        Organization.objects.all(), required=True,
        widget=autocomplete_light.ChoiceWidget('CustomerOrganization',)
    )


class SupQuotationAdminForm(QuotationAdminForm):
    owner = forms.ModelChoiceField(
        Organization.objects.filter(organization_type__category="sup"), required=True,
        widget=autocomplete_light.ChoiceWidget('SupplierOrganization',)
    )
    recipient = forms.ModelChoiceField(
        Organization.objects.filter(organization_type__category="sup"), required=True,
        widget=autocomplete_light.ChoiceWidget('SupplierOrganization',)
    )


class EmailAdminForm(forms.Form):
    contacts = forms.ModelMultipleChoiceField(
        required=True, label=_("Send To"), queryset=Contact.objects.none())
    other_emails = MultiEmailField(widget=forms.Textarea(
        attrs={'class': 'vLargeTextField'}),
        required=False,
        label=_("Other Email Addresses")
    )
    subject = forms.CharField(required=True, label=_("Subject"))
    attention_of = forms.CharField(required=False, label=_("Attention of"))
    message = forms.CharField(widget=forms.Textarea(
        attrs={'class': 'vLargeTextField'}),
        required=False,
        label=_("Message")
    )

    def __init__(self, *args, **kwargs):
        quotation = kwargs.pop('quotation', None)
        super(EmailAdminForm, self).__init__(*args, **kwargs)
        recipient_contacts = quotation.recipient.contacts.exclude(email__isnull=True)
        self.fields["contacts"].queryset = recipient_contacts
        try:
            self.fields['contacts'].initial = [quotation.contact.id]
        except Exception:
            pass
