# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.core.urlresolvers import reverse
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.quotation.models import Quotation
from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Quotation"),
            'display': "tabs",
            'children': [
                QuotationProjectModels(),
                QuotationModels(),
                QuotationRowModels(),
                VatRowModels(),
            ]
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class QuotationDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Quotation"),
            'display': "tabs",
            'children': [
                QuotationProjectModels(),
                QuotationModels(),
                QuotationRowModels(),
                VatRowModels(),
            ]
        })
        super(QuotationDashboard, self).__init__(**kwargs)


class QuotationProjectModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Quotation Project Models"),
            'models': (
                'jmb.quotation.models.QuotationProject',
                'jmb.quotation.models.SupplierQuotationProject',
                'jmb.quotation.models.CustomerQuotationProject',
            ),
        })
        super(QuotationProjectModels, self).__init__(**kwargs)


class QuotationModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Quotation Models"),
            'models': (
                'jmb.quotation.models.Quotation',
                'jmb.quotation.models.SupplierQuotation',
                'jmb.quotation.models.CustomerQuotation',
            ),
        })
        super(QuotationModels, self).__init__(**kwargs)


class QuotationRowModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Quotation Row Models"),
            'models': (
                'jmb.quotation.models.QuotationRow',
                'jmb.quotation.models.SupplierQuotationRow',
                'jmb.quotation.models.CustomerQuotationRow',
            ),
        })
        super(QuotationRowModels, self).__init__(**kwargs)


class VatRowModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Vat Row Models"),
            'models': (
                'jmb.quotation.models.VatRow',
                'jmb.quotation.models.SupplierVatRow',
                'jmb.quotation.models.CustomerVatRow',
            ),
        })
        super(VatRowModels, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# # Used in /admin
jmb_dashboard.register_group(QuotationDashboard, 'jmb.quotation')
# # Used in /admin/Quotation
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.quotation')
