# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings
import jmb.core.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('product', '__first__'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('price', '__first__'),
        ('vat', '0001_initial'),
        ('payment', '0001_initial'),
        ('currency', '0001_initial'),
        ('office', '0001_initial'),
        ('project', '0001_initial'),
        ('organization', '0002_auto_20160705_2208'),
        ('store', '__first__'),
        ('carriage', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Quotation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('description', models.CharField(max_length=255, verbose_name='Description', db_index=True)),
                ('full_description', jmb.core.db.fields.HTMLField(null=True, verbose_name='Full description', blank=True)),
                ('number', models.IntegerField(db_index=True, null=True, verbose_name='Number', db_column=b'qnumber', blank=True)),
                ('revision', models.IntegerField(db_index=True, null=True, verbose_name='Revision', blank=True)),
                ('revision_year', models.IntegerField(verbose_name='First revision year')),
                ('date_q', models.DateField(verbose_name='Date', db_index=True)),
                ('order_done', models.BooleanField(default=False, db_index=True, verbose_name='Ordered')),
                ('date_delivery', models.DateField(db_index=True, null=True, verbose_name='Date Delivery', blank=True)),
                ('quote_firm_for', models.CharField(max_length=255, null=True, verbose_name='Quote Firm For', blank=True)),
                ('delivery_window', models.CharField(max_length=255, null=True, verbose_name='Delivery Window', blank=True)),
                ('inspected', models.BooleanField(default=False, db_index=True, verbose_name='Inspected')),
                ('date_inspected', models.DateField(db_index=True, null=True, verbose_name='Inspected Date', blank=True)),
                ('submitted', models.BooleanField(default=False, db_index=True, verbose_name='Submitted')),
                ('date_submitted', models.DateField(db_index=True, null=True, verbose_name='Submitted Date', blank=True)),
                ('accepted', models.BooleanField(default=False, db_index=True, verbose_name='Accepted')),
                ('date_accepted', models.DateField(db_index=True, null=True, verbose_name='Accepted Date', blank=True)),
                ('total_income', models.DecimalField(default=0, verbose_name='Total Income', max_digits=9, decimal_places=2)),
                ('total_fee', models.DecimalField(default=0, verbose_name='Total Fee', max_digits=9, decimal_places=2)),
                ('total_discount', models.DecimalField(default=0, verbose_name='Total Discount', max_digits=9, decimal_places=2)),
                ('total_vat', models.DecimalField(default=0, verbose_name='Total VAT', max_digits=9, decimal_places=2)),
                ('note', models.TextField(null=True, verbose_name='Note', blank=True)),
                ('contact', models.ForeignKey(related_name='quotations', verbose_name='Contact', blank=True, to='organization.Contact', null=True)),
                ('creator', models.ForeignKey(related_name='quotation_quotation_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('currency', models.ForeignKey(related_name='quotations', verbose_name='Currency', blank=True, to='currency.Currency', null=True)),
                ('delivery', models.ForeignKey(related_name='quotations', verbose_name='Delivery', blank=True, to='carriage.Delivery', null=True)),
                ('last_modifier', models.ForeignKey(related_name='quotation_quotation_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('office', models.ForeignKey(related_name='quotations', verbose_name='Office', blank=True, to='office.Office', null=True)),
                ('owner', models.ForeignKey(related_name='owner_quotations', verbose_name='Bill to', to='organization.Organization')),
                ('payment_form', models.ForeignKey(related_name='quotations', verbose_name='Payment Form', blank=True, to='payment.PaymentForm', null=True)),
                ('price_list', models.ForeignKey(related_name='quotations', verbose_name='Prices List & Discount', blank=True, to='price.OrganizationPriceList', null=True)),
            ],
            options={
                'verbose_name': 'quotation',
                'verbose_name_plural': 'quotations',
            },
        ),
        migrations.CreateModel(
            name='QuotationProject',
            fields=[
                ('project_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='project.Project')),
            ],
            options={
                'abstract': False,
            },
            bases=('project.project',),
        ),
        migrations.CreateModel(
            name='QuotationRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('quantity', models.DecimalField(default=0, verbose_name='Quantity', max_digits=9, decimal_places=2)),
                ('m_unit', models.CharField(default=b'pz', max_length=2, verbose_name='Unit', db_index=True, choices=[(b'xx', b'yy')])),
                ('price', models.DecimalField(default=0, verbose_name='Price', max_digits=9, decimal_places=2)),
                ('labor_cost', models.DecimalField(default=0, verbose_name='Labor cost', max_digits=9, decimal_places=2)),
                ('material_cost', models.DecimalField(default=0, verbose_name='Matrial cost', max_digits=9, decimal_places=2)),
                ('services_cost', models.DecimalField(default=0, verbose_name='Services cost', max_digits=9, decimal_places=2)),
                ('recharge', models.DecimalField(default=0, verbose_name='recharge %', max_digits=4, decimal_places=2)),
                ('fee', models.DecimalField(default=0, verbose_name='Fee', max_digits=9, decimal_places=2)),
                ('discount', models.DecimalField(default=0, verbose_name='Discount', max_digits=9, decimal_places=2)),
                ('description', models.CharField(max_length=200, null=True, verbose_name='Description', blank=True)),
                ('long_description', models.TextField(null=True, verbose_name='Long Description', blank=True)),
                ('to_print', models.BooleanField(default=True, db_index=True, verbose_name='To Print')),
                ('summary', models.BooleanField(default=True, db_index=True, verbose_name='Summary')),
                ('creator', models.ForeignKey(related_name='quotation_quotationrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='quotation_quotationrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('product', models.ForeignKey(related_name='quotationrows', verbose_name='Product', to='product.Product')),
                ('project', models.ForeignKey(related_name='quotationrows', verbose_name='Project', blank=True, to='quotation.QuotationProject', null=True)),
                ('quotation', models.ForeignKey(related_name='rows', verbose_name='Quotation', to='quotation.Quotation')),
                ('store_cause', models.ForeignKey(related_name='quotationrows', verbose_name='Store Cause', to='store.StoreCause')),
                ('vat', models.ForeignKey(related_name='quotationrows', verbose_name='Vat', to='vat.Vat')),
            ],
            options={
                'ordering': ['-quotation__date_q', '-quotation__number', 'ordering', 'id'],
                'verbose_name': 'quotation row',
                'verbose_name_plural': 'quotation rows',
            },
        ),
        migrations.CreateModel(
            name='VatRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('total_income', models.DecimalField(verbose_name='Total Income', max_digits=9, decimal_places=2)),
                ('total_fee', models.DecimalField(verbose_name='Total Fee', max_digits=9, decimal_places=2)),
                ('total_discount', models.DecimalField(verbose_name='Total Discount', max_digits=9, decimal_places=2)),
                ('total_vat', models.DecimalField(verbose_name='Total Vat', max_digits=9, decimal_places=2)),
                ('creator', models.ForeignKey(related_name='quotation_vatrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='quotation_vatrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('quotation', models.ForeignKey(related_name='vattotalquotationrows', verbose_name='Quotation', to='quotation.Quotation')),
                ('vat', models.ForeignKey(related_name='vattotalquotationrows', verbose_name='Vat', to='vat.Vat')),
            ],
            options={
                'ordering': ('vat__ordering', 'vat__code'),
                'verbose_name': 'vat row',
                'verbose_name_plural': 'vat rows',
            },
        ),
        migrations.AddField(
            model_name='quotation',
            name='project',
            field=models.ForeignKey(related_name='quotations', verbose_name='Project', blank=True, to='quotation.QuotationProject', null=True),
        ),
        migrations.AddField(
            model_name='quotation',
            name='recipient',
            field=models.ForeignKey(related_name='recipient_quotations', verbose_name='Ship to', blank=True, to='organization.Organization', null=True),
        ),
        migrations.AddField(
            model_name='quotation',
            name='shipping_address',
            field=models.ForeignKey(related_name='quotations', verbose_name='Shipping Address', blank=True, to='organization.OrganizationAddress', null=True),
        ),
        migrations.AddField(
            model_name='quotation',
            name='store_cause',
            field=models.ForeignKey(related_name='quotations', verbose_name='Store Cause', to='store.StoreCause'),
        ),
        migrations.AddField(
            model_name='quotation',
            name='vat',
            field=models.ForeignKey(related_name='quotations', verbose_name='Vat', blank=True, to='vat.Vat', null=True),
        ),
        migrations.CreateModel(
            name='CustomerQuotation',
            fields=[
            ],
            options={
                'verbose_name': 'customer quotation',
                'proxy': True,
                'verbose_name_plural': 'customer quotations',
                'permissions': (('view_customer_quotation', 'Can VIEW Customer quotation'), ('list_customer_quotation', 'Can LIST Customer quotation')),
            },
            bases=('quotation.quotation',),
        ),
        migrations.CreateModel(
            name='CustomerQuotationProject',
            fields=[
            ],
            options={
                'verbose_name': 'customer quotation project',
                'proxy': True,
                'verbose_name_plural': 'customer quotation projects',
            },
            bases=('quotation.quotationproject',),
        ),
        migrations.CreateModel(
            name='CustomerQuotationRow',
            fields=[
            ],
            options={
                'ordering': ['-quotation__date_q', '-quotation__number', 'ordering', 'id'],
                'verbose_name': 'customer quotation row',
                'proxy': True,
                'verbose_name_plural': 'customer quotation rows',
                'permissions': (('view_customer_quotationrow', 'Can VIEW Customer quotation row'), ('list_customer_quotationrow', 'Can LIST Customer quotation row')),
            },
            bases=('quotation.quotationrow',),
        ),
        migrations.CreateModel(
            name='CustomerVatRow',
            fields=[
            ],
            options={
                'ordering': ('vat__ordering', 'vat__code'),
                'verbose_name': 'customer vat row',
                'proxy': True,
                'verbose_name_plural': 'customer vat rows',
                'permissions': (('view_customer_vatrow', 'Can VIEW Customer quotation row'), ('list_customer_vatrow', 'Can LIST Customer quotation row')),
            },
            bases=('quotation.vatrow',),
        ),
        migrations.CreateModel(
            name='SupplierQuotation',
            fields=[
            ],
            options={
                'verbose_name': 'supplier quotation',
                'proxy': True,
                'verbose_name_plural': 'supplier quotations',
                'permissions': (('view_supplier_quotation', 'Can VIEW Supplier quotation'), ('list_supplier_quotation', 'Can LIST Supplier quotation')),
            },
            bases=('quotation.quotation',),
        ),
        migrations.CreateModel(
            name='SupplierQuotationProject',
            fields=[
            ],
            options={
                'verbose_name': 'supplier quotation project',
                'proxy': True,
                'verbose_name_plural': 'supplier quotation projects',
            },
            bases=('quotation.quotationproject',),
        ),
        migrations.CreateModel(
            name='SupplierQuotationRow',
            fields=[
            ],
            options={
                'ordering': ['-quotation__date_q', '-quotation__number', 'ordering', 'id'],
                'verbose_name': 'supplier quotation row',
                'proxy': True,
                'verbose_name_plural': 'supplier quotation rows',
                'permissions': (('view_supplier_quotationrow', 'Can VIEW Supplier quotation row'), ('list_supplier_quotationrow', 'Can LIST Supplier quotation row')),
            },
            bases=('quotation.quotationrow',),
        ),
        migrations.CreateModel(
            name='SupplierVatRow',
            fields=[
            ],
            options={
                'ordering': ('vat__ordering', 'vat__code'),
                'verbose_name': 'supplier vat row',
                'proxy': True,
                'verbose_name_plural': 'supplier vat rows',
                'permissions': (('view_supplier_vatrow', 'Can VIEW Supplier quotation row'), ('list_supplier_vatrow', 'Can LIST Supplier quotation row')),
            },
            bases=('quotation.vatrow',),
        ),
    ]
