# -*- coding: utf-8 -*-
from datetime import date
from django.conf import settings
from django.db import models, transaction

from jmb.procedure.models import Procedure, ProcedureRow


class ProcedureMethods(models.Model):

    class Meta:
        abstract = True

    if "jmb.procedure" in settings.INSTALLED_APPS:

        @transaction.commit_manually
        def create_or_append_to_procedure(self, procedure=None, date_p=None):
            """
            crea o aggiunge ad una Pratica le Righe Preventivo
            """
            if not date_p:
                date_p = date.today()
            try:
                # se il Preventivo non è accettato esco
                if not self.accepted:
                    transaction.rollback()
                    return False, "Quotation is not accepted"

                # se il Preventivo è già stato trasformato esco
                if self.procedure_done:
                    transaction.rollback()
                    return False, "Quotation already ordered"

                quotationrows = self.rows.all()
                # se non ci sono righe da trasformare esco con errore
                if not quotationrows:
                    transaction.rollback()
                    return False, "There are not ordering rows"

                if not procedure:
                    procedure = Procedure(
                        owner=self.owner, recipient=self.recipient, project=self.project,
                        payment_form=self.payment_form, office=self.office,
                        contact=self.contact, currency=self.currency, delivery=self.delivery,
                        vat=self.vat, agent=self.agent,
                        price_list=self.price_list, vector=self.vector,
                        store_cause=self.store_cause,
                        description=self.description, date_p=date_p, note=self.note,
                        total_income=self.total_income, total_fee=self.total_fee,
                        total_discount=self.total_discount, total_vat=self.total_vat,
                        date_delivery=self.date_delivery, quote_firm_for=self.quote_firm_for,
                        delivery_window=self.delivery_window
                    )
                    procedure.save()

                for row in quotationrows:
                    message_row = row.add_to_procedure(procedure)

                if not message_row[0]:
                    transaction.rollback()
                    return message_row

                if procedure.rows.count() == 0:
                    transaction.rollback()
                    return False, "Error!!!"
            except Exception, e:
                transaction.rollback()
                return False, e

            # Preventivo Trasformato correttamente ed interamente
            try:
                self.procedure = True
                self.save()
                transaction.commit()
            except Exception, e:
                pass
            return True, ""


class ProcedureRowMethods(models.Model):

    class Meta:
        abstract = True

    if "procedure" in settings.INSTALLED_APPS:
        @transaction.commit_manually
        def add_to_procedure(self, procedure):
            # se il preventivo è già stato trasformato in ordine esco
            if self.quotation.procedure_done:
                transaction.rollback()
                return False, "Quotation already Ordered"
            try:
                procedurerow = ProcedureRow(
                    procedure=procedure, product=self.product, vat=self.vat,
                    store_cause=self.store_cause,
                    quantity=self.quantity, price=self.price, m_unit=self.m_unit,
                    fee=self.fee, discount=self.discount,
                    description=self.description, long_description=self.long_description
                )
                procedurerow.save()
            except Exception, e:
                transaction.rollback()
                return False, e
            transaction.commit()
            return True, ""
